import _JSXStyle from "next/dist/shared/lib/styled-jsx";
const Test = ()=><_JSXStyle id={"94239b6d6b42c9b5"}>{"p{color:red}"}</_JSXStyle>
;
export default (()=><div className={"jsx-3822e6e1fb9fa41a"}>

    <p className={"jsx-3822e6e1fb9fa41a"}>test</p>

    <_JSXStyle id={"b7efb453c85593c1"}>{"body{background:red}"}</_JSXStyle>

    <_JSXStyle id={"94239b6d6b42c9b5"}>{"p.jsx-3822e6e1fb9fa41a{color:red}"}</_JSXStyle>

  </div>
);
